@@ -4,7 +4,7 @@
 #' data frame or list with \code{NA}.
 #'
 #' @param x         a vector, factor, matrix, data frame, or list.
-#' @param as.na     a vector indicating values or characters to replace with \code{NA}.
+#' @param na     a vector indicating values or characters to replace with \code{NA}.
 #' @param check     logical: if \code{TRUE}, argument specification is checked.
 #'
 #' @author
@@ -28,40 +28,40 @@
 #' x.num <- c(1, 3, 2, 4, 5)
 #'
 #' # Replace 2 with NA
-#' as.na(x.num, as.na = 2)
+#' as.na(x.num, na = 2)
 #'
 #' # Replace 2, 3, and 4 with NA
-#' as.na(x.num, as.na = c(2, 3, 4))
+#' as.na(x.num, na = c(2, 3, 4))
 #'
 #' #--------------------------------------
 #' # Character vector
 #' x.chr <- c("a", "b", "c", "d", "e")
 #'
 #' # Replace "b" with NA
-#' as.na(x.chr, as.na = "b")
+#' as.na(x.chr, na = "b")
 #'
 #' # Replace "b", "c", and "d" with NA
-#' as.na(x.chr, as.na = c("b", "c", "d"))
+#' as.na(x.chr, na = c("b", "c", "d"))
 #'
 #' #--------------------------------------
 #' # Factor
 #' x.factor <- factor(c("a", "a", "b", "b", "c", "c"))
 #'
 #' # Replace "b" with NA
-#' as.na(x.factor, as.na = "b")
+#' as.na(x.factor, na = "b")
 #'
 #' # Replace "b" and "c" with NA
-#' as.na(x.factor, as.na = c("b", "c"))
+#' as.na(x.factor, na = c("b", "c"))
 #'
 #' #--------------------------------------
 #' # Matrix
 #' x.mat <- matrix(1:20, ncol = 4)
 #'
 #' # Replace 8 with NA
-#' as.na(x.mat, as.na = 8)
+#' as.na(x.mat, na = 8)
 #'
 #' # Replace 8, 14, and 20 with NA
-#' as.na(x.mat, as.na = c(8, 14, 20))
+#' as.na(x.mat, na = c(8, 14, 20))
 #'
 #' #--------------------------------------
 #' # Data frame
@@ -70,10 +70,10 @@
 #'                    x3 = c(3, 1, 2), stringsAsFactors = FALSE)
 #'
 #' # Replace 1 with NA
-#' as.na(x.df, as.na = 1)
+#' as.na(x.df, na = 1)
 #'
 #' # Replace 1 and 3 with NA
-#' as.na(x.df, as.na = c(1, 3))
+#' as.na(x.df, na = c(1, 3))
 #'
 #' #--------------------------------------
 #' # List
@@ -82,15 +82,15 @@
 #'                x3 = c(3, 1, 2, 3))
 #'
 #' # Replace 1 with NA
-#' as.na(x.list, as.na = 1)
-as.na <- function(x, as.na, check = TRUE) {
+#' as.na(x.list, na = 1)
+as.na <- function(x, na, check = TRUE) {
 
   ####################################################################################
   # Input Check
 
   #......
   # Check if input 'x' is missing
-  if (missing(x)) {
+  if (isTRUE(missing(x))) {
 
     stop("Please specify a vector, factor, matrix,  data frame or list for the argument 'x'.",
          call. = FALSE)
@@ -99,32 +99,32 @@ as.na <- function(x, as.na, check = TRUE) {
 
   #......
   # Check if input 'x' is NULL
-  if (is.null(x)) {
+  if (isTRUE(is.null(x))) {
 
     stop("Input specified for the argument 'x' is NULL.", call. = FALSE)
 
   }
 
   #......
-  # Check if input 'as.na' is missing
-  if (missing(as.na)) {
+  # Check if input 'na' is missing
+  if (isTRUE(missing(na))) {
 
-    stop("Please specify a numeric vector or character vector for the argument 'as.na'.",
+    stop("Please specify a numeric vector or character vector for the argument 'na'.",
          call. = FALSE)
 
   }
 
   #......
-  # Check if input 'as.na' is NULL
-  if (is.null(as.na)) {
+  # Check if input 'na' is NULL
+  if (isTRUE(is.null(na))) {
 
-    stop("Input specified for the argument 'as.na' is NULL.", call. = FALSE)
+    stop("Input specified for the argument 'na' is NULL.", call. = FALSE)
 
   }
 
   #......
   # Check input 'check'
-  if (!is.logical(check)) {
+  if (isTRUE(!is.logical(check))) {
 
     stop("Please specify TRUE or FALSE for the argument 'check'.", call. = FALSE)
 
@@ -136,7 +136,7 @@ as.na <- function(x, as.na, check = TRUE) {
 
     #......
     # Vector, factor, matrix, data frame, or list for the argument 'x'?
-    if (!is.atomic(x) && !is.factor(x) && !is.matrix(x) && !is.data.frame(x) && !is.list(x)) {
+    if (isTRUE(!is.atomic(x) && !is.factor(x) && !is.matrix(x) && !is.data.frame(x) && !is.list(x))) {
 
       stop("Please specifiy a vector, factor, matrix or data frame for the argument 'x'.",
            call. = FALSE)
@@ -144,30 +144,30 @@ as.na <- function(x, as.na, check = TRUE) {
     }
 
     #......
-    # Check input 'as.na': Values in 'as.na'?
+    # Check input 'na': Values in 'na'?
 
     # Factor or Vector
-    if (is.atomic(x) || is.factor(x)) {
+    if (isTRUE(is.atomic(x) || is.factor(x))) {
 
-      as.na.x <- !as.na %in% x
+      na.x <- !na %in% x
 
     # Matrix or data frame
-    } else if (is.matrix(x) || is.data.frame(x)) {
+    } else if (isTRUE(is.matrix(x) || is.data.frame(x))) {
 
-      as.na.x <- vapply(as.character(as.na), function(y) !y %in% misty::trim(apply(as.matrix(x), 2, as.character)),
+      na.x <- vapply(as.character(na), function(y) !y %in% misty::chr.trim(apply(as.matrix(x), 2, as.character)),
                         FUN.VALUE = logical(1))
 
     # List
-    } else if (is.list(x)) {
+    } else if (isTRUE(is.list(x))) {
 
-      as.na.x <- !as.na %in% unlist(x)
+      na.x <- !na %in% unlist(x)
 
     }
 
-    if (any(as.na.x)) {
+    if (isTRUE(any(na.x))) {
 
-      warning(paste0("Values specified in the argument 'as.na' were not found in 'x': ",
-                      paste(as.na[as.na.x], collapse = ", ")), call. = FALSE)
+      warning(paste0("Values specified in the argument 'na' were not found in 'x': ",
+                      paste(na[na.x], collapse = ", ")), call. = FALSE)
     }
 
   }
@@ -175,51 +175,51 @@ as.na <- function(x, as.na, check = TRUE) {
   ####################################################################################
   # Main Function
 
-  if (is.null(dim(x))) {
+  if (isTRUE(is.null(dim(x)))) {
 
     #---------------------------------
     # Factor
-    if (is.factor(x)) {
+    if (isTRUE(is.factor(x))) {
 
       f.levels <- sort(unique(as.numeric(x)))
       f.labels <- levels(x)
 
-      if (any(as.na %in% f.labels)) {
+      if (isTRUE(any(na %in% f.labels))) {
 
-        f.levels <- f.levels[-which(f.labels %in% as.na)]
-        f.labels <- f.labels[-which(f.labels %in% as.na)]
+        f.levels <- f.levels[-which(f.labels %in% na)]
+        f.labels <- f.labels[-which(f.labels %in% na)]
 
       }
 
-      object <- factor(ifelse(x %in% as.na, NA, x), levels = f.levels, labels = f.labels)
+      object <- factor(ifelse(x %in% na, NA, x), levels = f.levels, labels = f.labels)
 
     #---------------------------------
     # Vector
-    } else if (is.atomic(x)) {
+    } else if (isTRUE(is.atomic(x))) {
 
-      object <- ifelse(x %in% as.na, NA, x)
+      object <- ifelse(x %in% na, NA, x)
       names(object) <- names(x)
 
     #---------------------------------
     # List
-    } else if (is.list(x)) {
+    } else if (isTRUE(is.list(x))) {
 
-      object <- lapply(x, misty::as.na, as.na = as.na, check = FALSE)
+      object <- lapply(x, misty::as.na, na = na, check = FALSE)
       names(object) <- names(x)
 
     }
 
   #---------------------------------
   # Matrix
-  } else if (is.matrix(x)) {
+  } else if (isTRUE(is.matrix(x))) {
 
-    object <- apply(x, 2, misty::as.na, as.na = as.na, check = FALSE)
+    object <- apply(x, 2, misty::as.na, na = na, check = FALSE)
 
   #---------------------------------
   # Data frame
-  } else if (is.data.frame(x)) {
+  } else if (isTRUE(is.data.frame(x))) {
 
-    object <- data.frame(lapply(x, misty::as.na, as.na = as.na, check = FALSE),
+    object <- data.frame(lapply(x, misty::as.na, na = na, check = FALSE),
                          stringsAsFactors = FALSE)
 
   }
