@@ -50,7 +50,7 @@ na.coverage <- function(x, tri = c("both", "lower", "upper"), digits = 2, as.na
 
   #......
   # Check if input 'x' is missing
-  if (missing(x)) {
+  if (isTRUE(missing(x))) {
 
     stop("Please specify a matrix or data frame for the argument 'x'.",
          call. = FALSE)
@@ -59,7 +59,7 @@ na.coverage <- function(x, tri = c("both", "lower", "upper"), digits = 2, as.na
 
   #......
   # Check if input 'x' is NULL
-  if (is.null(x)) {
+  if (isTRUE(is.null(x))) {
 
     stop("Input specified for the argument 'x' is NULL.", call. = FALSE)
 
@@ -67,7 +67,7 @@ na.coverage <- function(x, tri = c("both", "lower", "upper"), digits = 2, as.na
 
   #......
   # Matrix or data frame for the argument 'x'?
-  if (!is.matrix(x) && !is.data.frame(x)) {
+  if (isTRUE(!is.matrix(x) && !is.data.frame(x))) {
 
     stop("Please specify a matrix or data frame for the argument 'x'.", call. = FALSE)
 
@@ -75,7 +75,7 @@ na.coverage <- function(x, tri = c("both", "lower", "upper"), digits = 2, as.na
 
   #.........................
   # Check input 'check'
-  if (!is.logical(check)) {
+  if (isTRUE(!is.logical(check))) {
 
     stop("Please specify TRUE or FALSE for the argument 'check'.", call. = FALSE)
 
@@ -87,7 +87,7 @@ na.coverage <- function(x, tri = c("both", "lower", "upper"), digits = 2, as.na
 
     #......
     # Check input 'tri'
-    if (any(!tri %in% c("both", "lower", "upper"))) {
+    if (isTRUE(any(!tri %in% c("both", "lower", "upper")))) {
 
       stop("Character string in the argument 'tri' does not match with \"both\", \"lower\", or \"upper\".",
            call. = FALSE)
@@ -96,7 +96,7 @@ na.coverage <- function(x, tri = c("both", "lower", "upper"), digits = 2, as.na
 
     #......
     # Check input 'digits'
-    if (digits %% 1L != 0L || digits < 0L) {
+    if (isTRUE(digits %% 1L != 0L || digits < 0L)) {
 
       stop("Specify a positive integer value for the argument 'digits'.", call. = FALSE)
 
@@ -104,7 +104,7 @@ na.coverage <- function(x, tri = c("both", "lower", "upper"), digits = 2, as.na
 
     #......
     # Check input 'output'
-    if (!is.logical(output)) {
+    if (isTRUE(!is.logical(output))) {
 
       stop("Please specify TRUE or FALSE for the argument 'output'.", call. = FALSE)
 
@@ -118,9 +118,9 @@ na.coverage <- function(x, tri = c("both", "lower", "upper"), digits = 2, as.na
   #-----------------------------------------------------------------------------------
   # Convert user-missing values into NA
 
-  if (!is.null(as.na)) {
+  if (isTRUE(!is.null(as.na))) {
 
-    x <- misty::as.na(x, as.na = as.na, check = check)
+    x <- misty::as.na(x, na = as.na, check = check)
 
   }
 
